==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2alpha1CronJobStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import org.joda.time.DateTime;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface V2alpha1CronJobStatusFluent<A extends V2alpha1CronJobStatusFluent<A>> extends Fluent<A>{


    public A addToActive(int index,V1ObjectReference item);
    public A setToActive(int index,V1ObjectReference item);
    public A addToActive(V1ObjectReference... items);
    public A addAllToActive(Collection<V1ObjectReference> items);
    public A removeFromActive(V1ObjectReference... items);
    public A removeAllFromActive(Collection<V1ObjectReference> items);
    
/**
 * This method has been deprecated, please use method buildActive instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ObjectReference> getActive();
    public List<V1ObjectReference> buildActive();
    public V1ObjectReference buildActive(int index);
    public V1ObjectReference buildFirstActive();
    public V1ObjectReference buildLastActive();
    public V1ObjectReference buildMatchingActive(io.kubernetes.client.fluent.Predicate<V1ObjectReferenceBuilder> predicate);
    public A withActive(List<V1ObjectReference> active);
    public A withActive(V1ObjectReference... active);
    public Boolean hasActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> addNewActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> addNewActiveLike(V1ObjectReference item);
    public V2alpha1CronJobStatusFluent.ActiveNested<A> setNewActiveLike(int index,V1ObjectReference item);
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editActive(int index);
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editFirstActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editLastActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editMatchingActive(io.kubernetes.client.fluent.Predicate<V1ObjectReferenceBuilder> predicate);
    public DateTime getLastScheduleTime();
    public A withLastScheduleTime(DateTime lastScheduleTime);
    public Boolean hasLastScheduleTime();
    public A withNewLastScheduleTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewLastScheduleTime(long arg0);
    public A withNewLastScheduleTime(Object arg0);

    public interface ActiveNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectReferenceFluent<V2alpha1CronJobStatusFluent.ActiveNested<N>>{

        
    public N and();    public N endActive();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2alpha1CronJobStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import org.joda.time.DateTime;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface V2alpha1CronJobStatusFluent<A extends V2alpha1CronJobStatusFluent<A>> extends Fluent<A>{


    public A addToActive(int index,V1ObjectReference item);
    public A setToActive(int index,V1ObjectReference item);
    public A addToActive(V1ObjectReference... items);
    public A addAllToActive(Collection<V1ObjectReference> items);
    public A removeFromActive(V1ObjectReference... items);
    public A removeAllFromActive(Collection<V1ObjectReference> items);
    
/**
 * This method has been deprecated, please use method buildActive instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ObjectReference> getActive();
    public List<V1ObjectReference> buildActive();
    public V1ObjectReference buildActive(int index);
    public V1ObjectReference buildFirstActive();
    public V1ObjectReference buildLastActive();
    public V1ObjectReference buildMatchingActive(io.kubernetes.client.fluent.Predicate<V1ObjectReferenceBuilder> predicate);
    public Boolean hasMatchingActive(io.kubernetes.client.fluent.Predicate<V1ObjectReferenceBuilder> predicate);
    public A withActive(List<V1ObjectReference> active);
    public A withActive(V1ObjectReference... active);
    public Boolean hasActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> addNewActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> addNewActiveLike(V1ObjectReference item);
    public V2alpha1CronJobStatusFluent.ActiveNested<A> setNewActiveLike(int index,V1ObjectReference item);
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editActive(int index);
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editFirstActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editLastActive();
    public V2alpha1CronJobStatusFluent.ActiveNested<A> editMatchingActive(io.kubernetes.client.fluent.Predicate<V1ObjectReferenceBuilder> predicate);
    public DateTime getLastScheduleTime();
    public A withLastScheduleTime(DateTime lastScheduleTime);
    public Boolean hasLastScheduleTime();
    public A withNewLastScheduleTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewLastScheduleTime(Object arg0);
    public A withNewLastScheduleTime(long arg0);

    public interface ActiveNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectReferenceFluent<V2alpha1CronJobStatusFluent.ActiveNested<N>>{

        
    public N and();    public N endActive();
}


}
